@@ -139,10 +139,11 @@ class ServiceUnitPlacement(object):
             return None
 
         svc_units = with_service['units']
-        if len(svc_units) <= unit_number:
+        if int(u_idx) >= len(svc_units):
             self.deployment.log.warning(
-                "Service:%s deploy-with Service:%s, but no with unit found",
-                svc.name, placement)
+                "Service:%s, Deploy-with-service:%s, Requested-unit-index=%s, "
+                "Cannot solve, falling back to default placement",
+                svc.name, placement, u_idx)
             return None
         unit_names = svc_units.keys()
         unit_names.sort()
